@@ -21,14 +21,9 @@ source $(dirname $0)/lib.sh
 
 showrun echo "starting"
 
-function _run_validate() {
-    # git-validation tool fails if $EPOCH_TEST_COMMIT is empty
-    # shellcheck disable=SC2154
-    if [[ -n "$EPOCH_TEST_COMMIT" ]]; then
-        showrun make validate
-    else
-        warn "Skipping git-validation since \$EPOCH_TEST_COMMIT is empty"
-    fi
+function _run_validate-source() {
+    showrun make validate-source
+
     # make sure PRs have tests
     showrun make tests-included
 }
@@ -61,14 +56,10 @@ function _run_compose_v2() {
 }
 
 function _run_int() {
-    _bail_if_test_can_be_skipped test/e2e
-
     dotest integration
 }
 
 function _run_sys() {
-    _bail_if_test_can_be_skipped test/system
-
     dotest system
 }
 
@@ -79,8 +70,6 @@ function _run_upgrade_test() {
 }
 
 function _run_bud() {
-    _bail_if_test_can_be_skipped test/buildah-bud
-
     showrun ./test/buildah-bud/run-buildah-bud-tests |& logformatter
 }
 
@@ -108,12 +97,6 @@ function _run_endpoint() {
     showrun make endpoint
 }
 
-function _run_minikube() {
-    _bail_if_test_can_be_skipped test/minikube
-    msg "Testing  minikube."
-    showrun bats test/minikube |& logformatter
-}
-
 function _run_farm() {
     _bail_if_test_can_be_skipped test/farm test/system
     msg "Testing podman farm."
@@ -141,6 +124,7 @@ exec_container() {
 
     # VM Images and Container images are built using (nearly) identical operations.
     set -x
+    env CONTAINERS_REGISTRIES_CONF=/dev/null bin/podman pull -q $CTR_FQIN
     # shellcheck disable=SC2154
     exec bin/podman run --rm --privileged --net=host --cgroupns=host \
         -v `mktemp -d -p /var/tmp`:/var/tmp:Z \
@@ -212,10 +196,18 @@ eof
 }
 
 function _run_build() {
+    local vb_target
+
+    # There's no reason to validate-binaries across multiple linux platforms
+    # shellcheck disable=SC2154
+    if [[ "$DISTRO_NV" =~ $FEDORA_NAME ]]; then
+        vb_target=validate-binaries
+    fi
+
     # Ensure always start from clean-slate with all vendor modules downloaded
     showrun make clean
     showrun make vendor
-    showrun make podman-release  # includes podman, podman-remote, and docs
+    showrun make podman-release $vb_target # includes podman, podman-remote, and docs
 
     # Last-minute confirmation that we're testing the desired runtime.
     # This Can't Possibly Fail™ in regular CI; only when updating VMs.
@@ -246,6 +238,10 @@ function _run_altbuild() {
     cd $GOSRC
     case "$ALT_NAME" in
         *Each*)
+            if [[ -z "$CIRRUS_PR" ]]; then
+                echo ".....only meaningful on PRs"
+                return
+            fi
             showrun git fetch origin
             # The make-and-check-size script, introduced 2022-03-22 in #13518,
             # runs 'make' (the original purpose of this check) against
@@ -257,7 +253,8 @@ function _run_altbuild() {
             context_dir=$(mktemp -d --tmpdir make-size-check.XXXXXXX)
             savedhead=$(git rev-parse HEAD)
             # Push to PR base. First run of the script will write size files
-            pr_base=$(git merge-base origin/$DEST_BRANCH HEAD)
+            # shellcheck disable=SC2154
+            pr_base=$PR_BASE_SHA
             showrun git checkout $pr_base
             showrun hack/make-and-check-size $context_dir
             # pop back to PR, and run incremental makes. Subsequent script
@@ -429,8 +426,6 @@ dotest() {
 }
 
 _run_machine-linux() {
-    _bail_if_test_can_be_skipped pkg/machine/e2e
-
     showrun make localmachine |& logformatter
 }
 
@@ -457,7 +452,9 @@ function _bail_if_test_can_be_skipped() {
     # Defined by Cirrus-CI for all tasks
     # shellcheck disable=SC2154
     head=$CIRRUS_CHANGE_IN_REPO
-    base=$(git merge-base $DEST_BRANCH $head)
+    # shellcheck disable=SC2154
+    base=$PR_BASE_SHA
+    echo "_bail_if_test_can_be_skipped: head=$head  base=$base"
     diffs=$(git diff --name-only $base $head)
 
     # If PR touches any files in an argument directory, we cannot skip
