@@ -18,7 +18,6 @@ import (
 
 	"github.com/sirupsen/logrus"
 
-	"github.com/containers/storage/pkg/parsers/kernel"
 	. "github.com/onsi/ginkgo/v2"    //nolint:revive,stylecheck
 	. "github.com/onsi/gomega"       //nolint:revive,stylecheck
 	. "github.com/onsi/gomega/gexec" //nolint:revive,stylecheck
@@ -376,11 +375,6 @@ func (s *PodmanSession) WaitWithTimeout(timeout int) {
 	os.Stderr.Sync()
 }
 
-// CreateTempDirInTempDir create a temp dir with prefix podman_test
-func CreateTempDirInTempDir() (string, error) {
-	return os.MkdirTemp("", "podman_test")
-}
-
 // SystemExec is used to exec a system command to check its exit code or output
 func SystemExec(command string, args []string) *PodmanSession {
 	c := exec.Command(command, args...)
@@ -453,27 +447,6 @@ func GetHostDistributionInfo() HostOS {
 	return host
 }
 
-// IsKernelNewerThan compares the current kernel version to one provided.  If
-// the kernel is equal to or greater, returns true
-func IsKernelNewerThan(version string) (bool, error) {
-	inputVersion, err := kernel.ParseRelease(version)
-	if err != nil {
-		return false, err
-	}
-	kv, err := kernel.GetKernelVersion()
-	if err != nil {
-		return false, err
-	}
-
-	// CompareKernelVersion compares two kernel.VersionInfo structs.
-	// Returns -1 if a < b, 0 if a == b, 1 it a > b
-	result := kernel.CompareKernelVersion(*kv, *inputVersion)
-	if result >= 0 {
-		return true, nil
-	}
-	return false, nil
-}
-
 // IsCommandAvailable check if command exist
 func IsCommandAvailable(command string) bool {
 	check := exec.Command("bash", "-c", strings.Join([]string{"command -v", command}, " "))
